@@ -47,10 +47,10 @@
 #include <ctype.h>
 #include <assert.h>
 #include <QtCore/QVariant>
-#include <QDebug>
+#include "khtml_debug.h"
 #include <stdlib.h>
 
-#include "kentities.c"
+#include "kentities_p.h"
 #include "htmlprospectivetokenizer.h"
 
 #define PROSPECTIVE_TOKENIZER_ENABLED 1
@@ -135,8 +135,8 @@ static const int sTokenizerYieldDelay = 450;
 HTMLTokenizer::HTMLTokenizer(DOM::DocumentImpl *_doc, KHTMLView *_view)
 {
     view = _view;
-    buffer = 0;
-    rawContent = 0;
+    buffer = nullptr;
+    rawContent = nullptr;
     rawContentSize = rawContentMaxSize = rawContentResync = rawContentSinceLastEntity = 0;
     charsets = KCharsets::charsets();
     parser = new KHTMLParser(_view, _doc);
@@ -144,7 +144,7 @@ HTMLTokenizer::HTMLTokenizer(DOM::DocumentImpl *_doc, KHTMLView *_view)
     m_externalScriptsTimerId = 0;
     m_tokenizerYieldDelay = sTokenizerFastYieldDelay;
     m_yieldTimer = 0;
-    m_prospectiveTokenizer = 0;
+    m_prospectiveTokenizer = nullptr;
     onHold = false;
     m_documentTokenizer = true;
     m_hasScriptsWaitingForStylesheets = false;
@@ -154,9 +154,9 @@ HTMLTokenizer::HTMLTokenizer(DOM::DocumentImpl *_doc, KHTMLView *_view)
 
 HTMLTokenizer::HTMLTokenizer(DOM::DocumentImpl *_doc, DOM::DocumentFragmentImpl *i)
 {
-    view = 0;
-    buffer = 0;
-    rawContent = 0;
+    view = nullptr;
+    buffer = nullptr;
+    rawContent = nullptr;
     rawContentSize = rawContentMaxSize = rawContentResync = rawContentSinceLastEntity = 0;
     charsets = KCharsets::charsets();
     parser = new KHTMLParser(i, _doc);
@@ -164,7 +164,7 @@ HTMLTokenizer::HTMLTokenizer(DOM::DocumentImpl *_doc, DOM::DocumentFragmentImpl
     m_externalScriptsTimerId = 0;
     m_tokenizerYieldDelay = sTokenizerFastYieldDelay;
     m_yieldTimer = 0;
-    m_prospectiveTokenizer = 0;
+    m_prospectiveTokenizer = nullptr;
     onHold = false;
     m_documentTokenizer = false;
     m_hasScriptsWaitingForStylesheets = false;
@@ -190,13 +190,13 @@ void HTMLTokenizer::reset()
     if (buffer) {
         KHTML_DELETE_QCHAR_VEC(buffer);
     }
-    buffer = dest = 0;
+    buffer = dest = nullptr;
     size = 0;
 
     if (rawContent) {
         KHTML_DELETE_QCHAR_VEC(rawContent);
     }
-    rawContent = 0;
+    rawContent = nullptr;
     rawContentSize = rawContentMaxSize = rawContentResync = 0;
 
     if (m_yieldTimer > 0) {
@@ -448,7 +448,7 @@ void HTMLTokenizer::scriptHandler()
     bool deferredScript = false;
 
     if (effectiveScript) {
-        CachedScript *cs = 0;
+        CachedScript *cs = nullptr;
 
         // forget what we just got, load from src url instead
         if (!currentScriptSrc.isEmpty() && javascript) {
@@ -1016,9 +1016,10 @@ void HTMLTokenizer::parseEntity(TokenizerString &src, QChar *&dest, bool start)
                 // be IE compatible and interpret even unterminated entities
                 // outside tags. like "foo &nbspstuff bla".
                 if (tag == NoTag) {
-                    const entity *e = kde_findEntity(cBuffer, cBufferPos);
-                    if (e && e->code < 256) {
-                        EntityChar = e->code;
+                    int code;
+                    const bool found = kde_findEntity(cBuffer, cBufferPos, &code);
+                    if (found && code < 256) {
+                        EntityChar = code;
                         entityLen = cBufferPos;
                     }
                 }
@@ -1028,11 +1029,12 @@ void HTMLTokenizer::parseEntity(TokenizerString &src, QChar *&dest, bool start)
             }
             if (Entity == SearchSemicolon) {
                 if (cBufferPos > 1) {
-                    const entity *e = kde_findEntity(cBuffer, cBufferPos);
+                    int code;
+                    const bool found = kde_findEntity(cBuffer, cBufferPos, &code);
                     // IE only accepts unterminated entities < 256,
                     // Gecko accepts them all, but only outside tags
-                    if (e && (tag == NoTag || e->code < 256 || *src == ';')) {
-                        EntityChar = e->code;
+                    if (found && (tag == NoTag || code < 256 || *src == ';')) {
+                        EntityChar = code;
                         entityLen = cBufferPos;
                     }
                 }
@@ -1041,7 +1043,7 @@ void HTMLTokenizer::parseEntity(TokenizerString &src, QChar *&dest, bool start)
         }
         case SearchSemicolon:
 #ifdef TOKEN_DEBUG
-            qDebug() << "ENTITY " << EntityChar.unicode();
+            qCDebug(KHTML_LOG) << "ENTITY " << EntityChar.unicode();
 #endif
             fixUpChar(EntityChar);
 
@@ -1059,7 +1061,7 @@ void HTMLTokenizer::parseEntity(TokenizerString &src, QChar *&dest, bool start)
                 rawContentSinceLastEntity = -1;
             } else {
 #ifdef TOKEN_DEBUG
-                qDebug() << "unknown entity!";
+                qCDebug(KHTML_LOG) << "unknown entity!";
 #endif
                 checkBuffer(11);
                 // ignore the sequence, add it to the buffer as plaintext
@@ -1113,7 +1115,7 @@ void HTMLTokenizer::parseTag(TokenizerString &src)
 
                     if (searchCount == 4) {
 #ifdef TOKEN_DEBUG
-                        qDebug() << "Found comment";
+                        qCDebug(KHTML_LOG) << "Found comment";
 #endif
                         // Found '<!--' sequence
                         ++src;
@@ -1206,13 +1208,13 @@ void HTMLTokenizer::parseTag(TokenizerString &src)
                     }
 #ifdef TOKEN_DEBUG
                     QByteArray tmp(ptr, len + 1);
-                    qDebug() << "Unknown tag: \"" << tmp.data() << "\"";
+                    qCDebug(KHTML_LOG) << "Unknown tag: \"" << tmp.data() << "\"";
 #endif
                 }
                 if (tagID) {
 #ifdef TOKEN_DEBUG
                     QByteArray tmp(ptr, len + 1);
-                    qDebug() << "found tag id=" << tagID << ": " << tmp.data();
+                    qCDebug(KHTML_LOG) << "found tag id=" << tagID << ": " << tmp.data();
 #endif
                     currToken.tid = beginTag ? tagID : tagID + ID_CLOSE_TAG;
                 }
@@ -1289,9 +1291,9 @@ void HTMLTokenizer::parseTag(TokenizerString &src)
                         *dest++ = a;
 #ifdef TOKEN_DEBUG
                         if (!a || (cBufferPos && *cBuffer == '!')) {
-                            qDebug() << "Unknown attribute: *" << QByteArray(cBuffer, cBufferPos + 1).data() << "*";
+                            qCDebug(KHTML_LOG) << "Unknown attribute: *" << QByteArray(cBuffer, cBufferPos + 1).data() << "*";
                         } else {
-                            qDebug() << "Known attribute: " << QByteArray(cBuffer, cBufferPos + 1).data();
+                            qCDebug(KHTML_LOG) << "Known attribute: " << QByteArray(cBuffer, cBufferPos + 1).data();
                         }
 #endif
 
@@ -1323,7 +1325,7 @@ void HTMLTokenizer::parseTag(TokenizerString &src)
                 if (curchar > ' ') {
                     if (curchar == '=') {
 #ifdef TOKEN_DEBUG
-                        qDebug() << "found equal";
+                        qCDebug(KHTML_LOG) << "found equal";
 #endif
                         tag = SearchValue;
                         ++src;
@@ -1468,7 +1470,7 @@ void HTMLTokenizer::parseTag(TokenizerString &src)
 
             uint tagID = currToken.tid;
 #if defined(TOKEN_DEBUG) && TOKEN_DEBUG > 0
-            qDebug() << "appending Tag: " << tagID;
+            qCDebug(KHTML_LOG) << "appending Tag: " << tagID;
 #endif
             // When parsing HTML flat tags like <div /> should
             // be ignored, the only exception is SCRIPT, and
@@ -1480,13 +1482,13 @@ void HTMLTokenizer::parseTag(TokenizerString &src)
             }
 
             bool beginTag = !currToken.flat && (tagID < ID_CLOSE_TAG);
-            HTMLScriptElementImpl *prevScriptElem = 0;
+            HTMLScriptElementImpl *prevScriptElem = nullptr;
 
             if (tagID >= ID_CLOSE_TAG) {
                 tagID -= ID_CLOSE_TAG;
             } else if (tagID == ID_SCRIPT) {
                 prevScriptElem = parser->currentScriptElement();
-                DOMStringImpl *a = 0;
+                DOMStringImpl *a = nullptr;
                 scriptSrc.clear(); scriptSrcCharset.clear();
                 if (currToken.attrs &&  /* potentially have a ATTR_SRC ? */
                         view &&  /* are we a regular tokenizer or just for innerHTML ? */
@@ -1638,7 +1640,7 @@ inline bool HTMLTokenizer::continueProcessing(int &processedCount)
 void HTMLTokenizer::write(const TokenizerString &str, bool appendData)
 {
 #ifdef TOKEN_DEBUG
-    qDebug() << this << " Tokenizer::write(\"" << str.toString() << "\"," << appendData << ")";
+    qCDebug(KHTML_LOG) << this << " Tokenizer::write(\"" << str.toString() << "\"," << appendData << ")";
 #endif
     if (!buffer) {
         return;
@@ -1894,7 +1896,7 @@ void HTMLTokenizer::timerEvent(QTimerEvent *e)
         }
         killTimer(m_externalScriptsTimerId);
         m_externalScriptsTimerId = 0;
-        notifyFinished(0);
+        notifyFinished(nullptr);
     }
 }
 
@@ -1914,9 +1916,9 @@ void HTMLTokenizer::end()
             KHTML_DELETE_QCHAR_VEC(rawContent);
         }
 
-        rawContent = 0;
+        rawContent = nullptr;
         rawContentSize = rawContentMaxSize = rawContentResync = 0;
-        buffer = 0;
+        buffer = nullptr;
     }
     emit finishedParsing();
 }
@@ -1953,7 +1955,7 @@ void HTMLTokenizer::finish()
             food.setUnicode(rawContent + pos + 1, rawContentSize - pos - 1); // deep copy
         }
         KHTML_DELETE_QCHAR_VEC(rawContent);
-        rawContent = 0;
+        rawContent = nullptr;
         rawContentSize = rawContentMaxSize = rawContentResync = 0;
 
         comment = server = title = false;
@@ -1971,7 +1973,7 @@ void HTMLTokenizer::finish()
 
 void HTMLTokenizer::processToken()
 {
-    KJSProxy *jsProxy = view ? view->part()->jScript() : 0L;
+    KJSProxy *jsProxy = view ? view->part()->jScript() : nullptr;
     if (jsProxy) {
         jsProxy->setEventHandlerLineno(tagStartLineno);
     }
@@ -2005,23 +2007,23 @@ void HTMLTokenizer::processToken()
     if (currToken.text) {
         text = QString::fromRawData(currToken.text->s, currToken.text->l);
     }
-    qDebug() << "Token -->" << LocalName::fromId(localNamePart(rid)).toString()
+    qCDebug(KHTML_LOG) << "Token -->" << LocalName::fromId(localNamePart(rid)).toString()
              << "id =" << currToken.tid << "closing =" << closing;
     if (currToken.flat) {
-        qDebug() << "Token is FLAT!";
+        qCDebug(KHTML_LOG) << "Token is FLAT!";
     }
     if (!text.isNull()) {
-        qDebug() << "text: \"" << text << "\"";
+        qCDebug(KHTML_LOG) << "text: \"" << text << "\"";
     }
     unsigned long l = currToken.attrs ? currToken.attrs->length() : 0;
 
     if (l) {
-        qDebug() << "Attributes: " << l;
+        qCDebug(KHTML_LOG) << "Attributes: " << l;
         for (unsigned long i = 0; i < l; ++i) {
             NodeImpl::Id tid = currToken.attrs->idAt(i);
             DOMString value = currToken.attrs->valueAt(i);
-            qDebug() << "    " << tid << " " << LocalName::fromId(localNamePart(tid)).toString()
-                     << "=\"" << value.string() << "\"" << endl;
+            qCDebug(KHTML_LOG) << "    " << tid << " " << LocalName::fromId(localNamePart(tid)).toString()
+                     << "=\"" << value.string() << "\"";
         }
     }
 #endif
@@ -2048,7 +2050,7 @@ void HTMLTokenizer::processToken()
 
 void HTMLTokenizer::processDoctypeToken()
 {
-    // qDebug() << "Process DoctypeToken (name: " << doctypeToken.name << ", publicID: " << doctypeToken.publicID << ", systemID: " << doctypeToken.systemID;
+    // qCDebug(KHTML_LOG) << "Process DoctypeToken (name: " << doctypeToken.name << ", publicID: " << doctypeToken.publicID << ", systemID: " << doctypeToken.systemID;
     doctypeToken.publicID = doctypeToken.publicID.simplified();
     doctypeToken.systemID = doctypeToken.systemID.simplified();
     parser->parseDoctypeToken(&doctypeToken);
@@ -2086,10 +2088,10 @@ void HTMLTokenizer::notifyFinished(CachedObject *finishedObj)
     // FIXME: This needs to be done for inline scripts too.
     m_hasScriptsWaitingForStylesheets = !parser->doc()->haveStylesheetsLoaded();
     if (m_hasScriptsWaitingForStylesheets) {
-        // qDebug() << "Delaying script execution until stylesheets have loaded.";
+        // qCDebug(KHTML_LOG) << "Delaying script execution until stylesheets have loaded.";
         return;
     }
-    // qDebug() << (finishedObj ? "Processing an external script"  : "Continuing processing of delayed external scripts");
+    // qCDebug(KHTML_LOG) << (finishedObj ? "Processing an external script"  : "Continuing processing of delayed external scripts");
 
     bool done = false;
     m_scriptTime.start();
@@ -2101,7 +2103,7 @@ void HTMLTokenizer::notifyFinished(CachedObject *finishedObj)
         CachedScript *cs = cachedScript.dequeue();
         DOMString scriptSource = cs->script();
 #ifdef TOKEN_DEBUG
-        qDebug() << "External script is:" << endl << scriptSource.string();
+        qCDebug(KHTML_LOG) << "External script is:" << endl << scriptSource.string();
 #endif
         setSrc(TokenizerString());
 
@@ -2154,7 +2156,7 @@ void HTMLTokenizer::executeScriptsWaitingForStylesheets()
 {
     assert(parser->doc()->haveStylesheetsLoaded());
     if (m_hasScriptsWaitingForStylesheets) {
-        notifyFinished(0);
+        notifyFinished(nullptr);
     }
 }
 
